@@ -4,7 +4,8 @@ use parent qw( Parse::Taxonomy );
 use Carp;
 use Text::CSV;
 use Scalar::Util qw( reftype );
-our $VERSION = '0.06';
+use Cwd;
+our $VERSION = '0.07';
 use Parse::Taxonomy::Auxiliary qw(
     path_check_fields
     components_check_fields
@@ -69,7 +70,7 @@ The name of the column in the header row under which each data record's parent
 ID can be found.  (Will be empty in the case of top-level nodes, as they have
 no parent.)  Defaults to C<parent_id>.
 
-=item * C<component_col>
+=item * C<leaf_col>
 
 The name of the column in the header row under which, in each data record, there
 is a found a string which differentiates that record from all other records
@@ -182,14 +183,14 @@ sub new {
     croak "Argument to 'new()' must have either 'file' or 'components' element but not both"
         if ($args->{file} and $args->{components});
 
-    $data->{id_col}           = $args->{id_col}
+    $data->{id_col}         = $args->{id_col}
                                 ? delete $args->{id_col}
                                 : 'id';
-    $data->{parent_id_col}    = $args->{parent_id_col}
+    $data->{parent_id_col}  = $args->{parent_id_col}
                                 ? delete $args->{parent_id_col}
                                 : 'parent_id';
-    $data->{component_col}    = $args->{component_col}
-                                ? delete $args->{component_col}
+    $data->{leaf_col}       = $args->{leaf_col}
+                                ? delete $args->{leaf_col}
                                 : 'name';
 
     if ($args->{components}) {
@@ -252,7 +253,7 @@ sub _check_required_columns {
     my ($data, $fields_ref) = @_;
     my %col2idx = map { $fields_ref->[$_] => $_ } (0 .. $#{$fields_ref});
     my %missing_columns = ();
-    my %main_columns = map { $_ => 1 } ( qw| id_col parent_id_col component_col | );
+    my %main_columns = map { $_ => 1 } ( qw| id_col parent_id_col leaf_col | );
     for my $c ( keys %main_columns ) {
         if (! exists $col2idx{$data->{$c}}) {
             $missing_columns{$c} = $data->{$c};
@@ -298,7 +299,7 @@ sub _prepare_data_records {
             push @bad_count_records,
                 [ $rec->[$data->{id_col_idx}], $this_row_count ];
         }
-        if (! length($rec->[$data->{component_col_idx}])) {
+        if (! length($rec->[$data->{leaf_col_idx}])) {
             push @nameless_component_records, $rec->[$data->{id_col_idx}];
         }
     }
@@ -334,11 +335,11 @@ ERROR_MSG_WRONG_COUNT
     }
     croak $error_msg if @bad_count_records;
 
-    $error_msg = <<NAMELESS_COMPONENT;
-Each data record must have a non-empty string in its 'component' column.
+    $error_msg = <<NAMELESS_LEAF;
+Each data record must have a non-empty string in its 'leaf' column.
 The following records (identified by the value in their '$data->{id_col}' columns)
-lack valid components:
-NAMELESS_COMPONENT
+lack valid leaves:
+NAMELESS_LEAF
     for my $rec (@nameless_component_records) {
         $error_msg .= "  id: $rec\n";
     }
@@ -365,12 +366,12 @@ ERROR_MSG_MISSING_PARENT
     my %families = ();
     for my $rec (@{$data_records}) {
         if (length($rec->[$data->{parent_id_col_idx}])) {
-            $families{$rec->[$data->{parent_id_col_idx}]}{$rec->[$data->{component_col_idx}]}++;
+            $families{$rec->[$data->{parent_id_col_idx}]}{$rec->[$data->{leaf_col_idx}]}++;
         }
     }
     $error_msg = <<ERROR_MSG_SIBLINGS_NAMED_SAME;
 No record with a non-null value in the '$data->{parent_id_col}' column
-may have two children with the same value in the '$data->{component_col}' column.
+may have two children with the same value in the '$data->{leaf_col}' column.
 The following are violations:
 ERROR_MSG_SIBLINGS_NAMED_SAME
 
@@ -378,7 +379,7 @@ ERROR_MSG_SIBLINGS_NAMED_SAME
     for my $k (sort {$a <=> $b} keys %families) {
         for my $l (sort keys %{$families{$k}}) {
             if ($families{$k}{$l} > 1) {
-                $error_msg .= "  $data->{parent_id_col}: $k|$data->{component_col}: $l|count of $data->{component_col}s: $families{$k}{$l}\n";
+                $error_msg .= "  $data->{parent_id_col}: $k|$data->{leaf_col}: $l|count of $data->{leaf_col}s: $families{$k}{$l}\n";
                 $same_names++;
             }
         }
@@ -490,9 +491,9 @@ of the column in the header row.  The other methods return strings.
 
     $name_of_parent_id_column = $self->parent_id_col;
 
-    $index_of_component_column = $self->component_col_idx;
+    $index_of_leaf_column = $self->leaf_col_idx;
 
-    $name_of_component_column = $self->component_col;
+    $name_of_leaf_column = $self->leaf_col;
 
 =cut
 
@@ -516,14 +517,14 @@ sub parent_id_col {
     return $self->{parent_id_col};
 }
 
-sub component_col_idx {
+sub leaf_col_idx {
     my $self = shift;
-    return $self->{component_col_idx};
+    return $self->{leaf_col_idx};
 }
 
-sub component_col {
+sub leaf_col {
     my $self = shift;
-    return $self->{component_col};
+    return $self->{leaf_col};
 }
 
 =head2 C<pathify()>
@@ -710,7 +711,7 @@ sub pathify {
         unless (
             ($f eq $self->id_col) or
             ($f eq $self->parent_id_col) or
-            ($f eq $self->component_col)
+            ($f eq $self->leaf_col)
         ) {
             push @fields_out, $f;
         }
@@ -721,14 +722,14 @@ sub pathify {
 
     my %hashed_data =  map { $_->[$self->id_col_idx] => {
         parent_id       => $_->[$self->parent_id_col_idx],
-        component       => $_->[$self->component_col_idx],
+        leaf       => $_->[$self->leaf_col_idx],
     } } @{$self->data_records};
 
     my @this_path = ();
     my $code;
     $code = sub {
         my $id = shift;
-        push @this_path, $hashed_data{$id}{component};
+        push @this_path, $hashed_data{$id}{leaf};
         my $parent_id = $hashed_data{$id}{parent_id};
         if (length($parent_id)) {
             &{$code}($parent_id);
@@ -758,6 +759,141 @@ sub pathify {
     return \@rewritten;
 }
 
+=head2 C<write_pathified_to_csv()>
+
+=over 4
+
+=item * Purpose
+
+Create a CSV-formatted file holding the data returned by C<pathify()>.
+
+=item * Arguments
+
+    $csv_file = $obj->write_pathified_to_csv( {
+       pathified => $pathified,                   # output of pathify()
+       csvfile => './t/data/taxonomy_out5.csv',
+    } );
+
+Single hash reference.  That hash is keyed on:
+
+=over 4
+
+=item * C<pathified>
+
+B<Required:>  Its value must be the arrayref of hash references returned by
+the C<pathify()> method.
+
+=item * C<csvfile>
+
+Optional.  Path to location where a CSV-formatted text file holding the
+taxonomy-by-index will be written.  Defaults to a file called
+F<taxonomy_out.csv> in the current working directory.
+
+=item * Text::CSV options
+
+You can also pass through any key-value pairs normally accepted by
+F<Text::CSV>.
+
+=back
+
+=item * Return Value
+
+Returns path to CSV-formatted text file just created.
+
+=item * Example
+
+Suppose we have a CSV-formatted file holding the following taxonomy-by-index:
+
+    "id","parent_id","name","is_actionable"
+    "1","","Alpha","0"
+    "2","","Beta","0"
+    "3","1","Epsilon","0"
+    "4","3","Kappa","1"
+    "5","1","Zeta","0"
+    "6","5","Lambda","1"
+    "7","5","Mu","0"
+    "8","2","Eta","1"
+    "9","2","Theta","1"
+
+After running this file through C<new()>, C<pathify()> and
+C<write_pathified_to_csv()> we will have a new CSV-formatted file holding
+this taxonomy-by-path:
+TK
+Note that the C<id>, C<parent_id> and C<name> columns have been replaced by the <path> column.
+
+=back
+
+=cut
+
+sub write_pathified_to_csv {
+    my ($self, $args) = @_;
+    if (defined $args) {
+        croak "Argument to 'pathify()' must be hashref"
+            unless (ref($args) and reftype($args) eq 'HASH');
+        croak "Argument to 'pathify()' must have 'pathified' element"
+            unless exists $args->{pathified};
+        croak "Argument 'pathified' must be array reference"
+            unless (ref($args->{pathified}) and
+                reftype($args->{pathified}) eq 'ARRAY');
+    }
+    else {
+        croak "write_pathified_to_csv() must be supplied with hashref"
+    }
+    my $pathified = $args->{pathified};
+    delete $args->{pathified};
+
+    # Test whether we're working with first element array ref or first element
+    # string
+    my $path_as_string = (! ref($pathified->[1]->[0])) ? 1 : 0;
+
+    my $columns_in = $self->fields;
+    my %path_columns = map {$_ => 1} (
+        $self->{id_col},
+        $self->{parent_id_col},
+        $self->{leaf_col},
+    );
+    my @non_path_columns_in =
+        map { $columns_in->[$_]  }
+        grep { ! $path_columns{$columns_in->[$_]} }
+        (0..$#{$columns_in});
+    my @columns_out = (qw| path |);
+    push @columns_out, @non_path_columns_in;
+
+    my $cwd = cwd();
+    my $csvfile = defined($args->{csvfile})
+        ? $args->{csvfile}
+        : "$cwd/taxonomy_out.csv";
+    delete $args->{csvfile};
+
+    # By this point, we should have processed all args other than those
+    # intended for Text::CSV and assigned their contents to variables as
+    # needed.
+
+    my $csv_args = { binary => 1 };
+    while (my ($k,$v) = each %{$args}) {
+        $csv_args->{$k} = $v;
+    }
+    my $csv = Text::CSV->new($csv_args);
+    open my $OUT, ">:encoding(utf8)", $csvfile
+        or croak "Unable to open $csvfile for writing";
+    $csv->eol(defined($csv_args->{eol}) ? $csv_args->{eol} : "\n");
+    $csv->print($OUT, [@columns_out]);
+    for my $rec (@{$pathified}[1..$#{$pathified}]) {
+        $csv->print(
+            $OUT,
+            $path_as_string
+                ? $rec
+                : [
+                    join('|' => @{$rec->[0]}),
+                    @{$rec}[1..$#columns_out]
+                  ]
+        );
+    }
+    close $OUT or croak "Unable to close $csvfile after writing";
+
+    return $csvfile;
+}
+
 1;
 
 # vim: formatoptions=crqot
